nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Spi

Struct Spi 

pub struct Spi { /* private fields */ }
Serial Peripheral Interfaces (SPI)

Implementations

Source

impl Spi

pub const unsafe fn from_ptr(ptr: *mut ()) -> Self

pub const fn as_ptr(&self) -> *mut ()

pub const fn cfg(self) -> Reg<Cfg, RW>

SPI Configuration register

pub const fn dly(self) -> Reg<Dly, RW>

SPI Delay register

pub const fn stat(self) -> Reg<Stat, RW>

SPI Status. Some status flags can be cleared by writing a 1 to that bit position.

pub const fn intenset(self) -> Reg<Intenset, RW>

SPI Interrupt Enable read and Set. A complete value may be read from this register. Writing a 1 to any implemented bit position causes that bit to be set.

pub const fn intenclr(self) -> Reg<Intenclr, W>

SPI Interrupt Enable Clear. Writing a 1 to any implemented bit position causes the corresponding bit in INTENSET to be cleared.

pub const fn div(self) -> Reg<Div, RW>

SPI clock Divider

pub const fn intstat(self) -> Reg<Intstat, R>

SPI Interrupt Status

pub const fn fifocfg(self) -> Reg<Fifocfg, RW>

FIFO configuration and enable register.

pub const fn fifostat(self) -> Reg<Fifostat, RW>

FIFO status register.

pub const fn fifotrig(self) -> Reg<Fifotrig, RW>

FIFO trigger settings for interrupt and DMA request.

pub const fn fifointenset(self) -> Reg<Fifointenset, RW>

FIFO interrupt enable set (enable) and read register.

pub const fn fifointenclr(self) -> Reg<Fifointenclr, RW>

FIFO interrupt enable clear (disable) and read register.

pub const fn fifointstat(self) -> Reg<Fifointstat, R>

FIFO interrupt status register.

pub const fn fifowr(self) -> Reg<Fifowr, W>

FIFO write data.

pub const fn fiford(self) -> Reg<Fiford, R>

FIFO read data.

pub const fn fifordnopop(self) -> Reg<Fifordnopop, R>

FIFO data read with no FIFO pop.

pub const fn fifosize(self) -> Reg<Fifosize, RW>

FIFO size register

pub const fn id(self) -> Reg<Id, R>

Peripheral identification register.